@@ -59,6 +59,7 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.4",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.5",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.6",
+    "Environment :: GPU :: NVIDIA CUDA :: 13",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -131,6 +132,8 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 5.0",
     "Framework :: Django :: 5.1",
     "Framework :: Django :: 5.2",
+    "Framework :: Django :: 6",
+    "Framework :: Django :: 6.0",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -143,6 +146,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django CMS :: 4.0",
     "Framework :: Django CMS :: 4.1",
     "Framework :: Django CMS :: 5.0",
+    "Framework :: Django CMS :: 5.1",
     "Framework :: FastAPI",
     "Framework :: Flake8",
     "Framework :: Flask",
@@ -150,6 +154,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Hypothesis",
     "Framework :: IDLE",
     "Framework :: IPython",
+    "Framework :: InvenTree",
     "Framework :: Jupyter",
     "Framework :: Jupyter :: JupyterLab",
     "Framework :: Jupyter :: JupyterLab :: 1",
@@ -178,6 +183,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 16.0",
     "Framework :: Odoo :: 17.0",
     "Framework :: Odoo :: 18.0",
+    "Framework :: Odoo :: 19.0",
     "Framework :: OpenTelemetry",
     "Framework :: OpenTelemetry :: Distros",
     "Framework :: OpenTelemetry :: Exporters",
@@ -249,6 +255,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Zope :: 3",
     "Framework :: Zope :: 4",
     "Framework :: Zope :: 5",
+    "Framework :: Zope :: 6",
     "Framework :: aiohttp",
     "Framework :: cocotb",
     "Framework :: napari",
@@ -353,6 +360,7 @@ sorted_classifiers: List[str] = [
     "License :: Repoze Public License",
     "Natural Language :: Afrikaans",
     "Natural Language :: Arabic",
+    "Natural Language :: Armenian",
     "Natural Language :: Basque",
     "Natural Language :: Bengali",
     "Natural Language :: Bosnian",
@@ -368,6 +376,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Dutch",
     "Natural Language :: English",
     "Natural Language :: Esperanto",
+    "Natural Language :: Estonian",
     "Natural Language :: Finnish",
     "Natural Language :: French",
     "Natural Language :: Galician",
@@ -412,6 +421,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Ukrainian",
     "Natural Language :: Urdu",
     "Natural Language :: Vietnamese",
+    "Natural Language :: Yiddish",
     "Operating System :: Android",
     "Operating System :: BeOS",
     "Operating System :: MacOS",
@@ -527,8 +537,14 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Python :: 3.13",
     "Programming Language :: Python :: 3.14",
     "Programming Language :: Python :: 3.15",
+    "Programming Language :: Python :: Free Threading",
+    "Programming Language :: Python :: Free Threading :: 1 - Unstable",
+    "Programming Language :: Python :: Free Threading :: 2 - Beta",
+    "Programming Language :: Python :: Free Threading :: 3 - Stable",
+    "Programming Language :: Python :: Free Threading :: 4 - Resilient",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
+    "Programming Language :: Python :: Implementation :: GraalPy",
     "Programming Language :: Python :: Implementation :: IronPython",
     "Programming Language :: Python :: Implementation :: Jython",
     "Programming Language :: Python :: Implementation :: MicroPython",
@@ -548,6 +564,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Visual Basic",
     "Programming Language :: XBasic",
     "Programming Language :: YACC",
+    "Programming Language :: Zig",
     "Programming Language :: Zope",
     "Topic :: Adaptive Technologies",
     "Topic :: Artistic Software",
@@ -731,6 +748,8 @@ sorted_classifiers: List[str] = [
     "Topic :: Scientific/Engineering :: Image Processing",
     "Topic :: Scientific/Engineering :: Image Recognition",
     "Topic :: Scientific/Engineering :: Information Analysis",
+    "Topic :: Scientific/Engineering :: Instrument Drivers",
+    "Topic :: Scientific/Engineering :: Instrument Drivers :: IVI Conformant",
     "Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator",
     "Topic :: Scientific/Engineering :: Mathematics",
     "Topic :: Scientific/Engineering :: Medical Science Apps.",
